local MinBuild, MaxBuild, Build = 40000, 0, select(4, GetBuildInfo())
if Build < MinBuild or ( MaxBuild > 0 and Build > MaxBuild ) then return end
local AddonName, a = ...
local AddonTitle = select(2, GetAddOnInfo(AddonName))
local PlainAddonTitle = AddonTitle:gsub("|c........", ""):gsub("|r", "")
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables

local c = BittensSpellFlashLibrary2

function a.hasThreeHolyPower()
    return s.Power("player", SPELL_POWER_HOLY_POWER) == 3
end

------------------------------------------------------------------------ common
a.spells["Avenging Wrath"] = {
    ID = 31884,
    NonGCD = true,
    FlashColor = "yellow",
}

a.spells["Word of Glory"] = {
    ID = 85673,
}

a.spells["Word of Glory at 90"] = {
    ID = 85673,
    Unit = "player",
    CheckFirst = function()
        return a.hasThreeHolyPower() 
            and s.HealthPercent("player") < 90
    end
}

a.spells["Crusader Strike"] = {
    ID = 35395,
}

a.spells["Crusader Strike for Holy Power"] = {
    ID = 35395,
    CheckFirst = function()
        return not a.hasThreeHolyPower()
    end
}

a.spells["Seal of Truth"] = {
    ID = 31801,
    FlashColor = "yellow",
    CheckFirst = function()
        return not c.HasBuff("Seal of Truth", 0, 15 * 60)
    end
}

a.spells["Seal of Insight"] = {
    ID = 20165,
    FlashColor = "yellow",
    CheckFirst = function()
        return not c.HasBuff("Seal of Insight", 0, 15 * 60)
    end
}

a.spells["Hammer of Wrath"] = {
    ID = 24275,
}

a.spells["Judgement"] = {
    ID = 20271,
}

a.spells["Judgement for Buff"] = {
    ID = 20271,
    FlashColor = "yellow",
    EvenIfNotUsable = 1,
    NoRangeCheck = 1,
    CheckFirst = function()
        return not c.HasBuff("Judgements of the Pure")
    end
}

a.spells["Consecration over 50"] = {
    ID = 26573,
    CheckFirst = function()
        return s.PowerPercent("player") > 50
    end
}

a.spells["Holy Wrath"] = {
    ID = 2812,
}

a.spells["Divine Plea"] = {
    ID = 54428,
}

-------------------------------------------------------------------------- holy
a.spells["Infusion of Light"] = { ID = 54149 }
a.spells["Daybreak"] = { ID = 88819 }
a.spells["Judgements of the Pure"] = { ID = 53657 }

a.spells["Word of Glory at 3"] = {
    ID = 85673,
    Unit = "player",
    FlashColor = "yellow",
    EvenIfNotUsable = 1,
    CheckFirst = function()
        return a.hasThreeHolyPower() 
    end
}

a.spells["Holy Shock"] = {
    ID = 20473,
    EvenIfNotUsable = 1,
    FlashColor = "yellow",
    CheckFirst = function()
        return c.HasBuff("Daybreak")
    end
}

a.spells["Fast Divine Light"] = {
    ID = 82326,
    EvenIfNotUsable = 1,
    FlashColor = "yellow",
    Override = function()
        return c.HasBuff("Infusion of Light")
    end
}

a.spells["Holy Radiance"] = {
    ID = 82327,
    EvenIfNotUsable = 1,
    FlashColor = "yellow",
}

a.spells["Beacon of Light"] = {
    ID = 53563,
    FlashColor = "yellow",
    Override = function()
        if GetNumPartyMembers() < 1 and GetNumRaidMembers() < 2 then
            return false
        end
        
        if not a.BeaconTarget then
            return true
        end
        
        if s.InCombat() then
            return not s.MyBuff(53563, a.BeaconTarget)
        else
            return s.MyBuffDuration(53563, a.BeaconTarget) < 2 * 60
        end
    end
}

-------------------------------------------------------------------- protection
a.spells["Grand Crusader"] = { ID = 98057 }
a.spells["Elusive"] = { ID = 107951 }

a.spells["Shield of the Righteous unless WoG"] = {
    ID = 53600,
    CheckFirst = function()
        return a.hasThreeHolyPower() and c.GetCooldown("Word of Glory") > 10
    end
}

a.spells["Avenger's Shield"] = {
    ID = 31935,
}

a.spells["Avenger's Shield for Holy Power"] = {
    ID = 31935,
    CheckFirst = function()
        return c.HasBuff("Grand Crusader")
    end
}

a.spells["Ardent Defender"] = {
    ID = 31850,
    NoGCD = true,
}

a.spells["Holy Shield"] = {
    ID = 20925,
    NoGCD = true,
}

a.spells["Divine Protection"] = {
    ID = 498,
    NoGCD = true,
}

a.spells["Fire of the Deep"] = {
    Type = "item",
    ID = 77117,
    Buff = "Elusive"
}

a.spells["Guardian of Ancient Kings"] = {
    ID = 86150,
    NoGCD = true,
}

a.spells["Judgements of the Just"] = {
    ID = 20271,
    Debuff = c.SLOW_MELEE_DEBUFFS,
    EarlyRefresh = 3,
}

a.spells["Delayed Judgement"] = {
    ID = 20271,
    CheckFirst = function()
        return a.GetConfig("Prot_2pT13")
    end
}

a.spells["Vindication"] = {
    ID = 35395,
    Debuff = c.WEAKEN_DEBUFFS,
    EarlyRefresh = 3,
}

a.spells["Righteous Fury"] = {
    ID = 25780,
    Buff = 25780,
    BuffUnit = "player",
    FlashColor = "yellow",
}

a.spells["Holy Wrath to Stun"] = {
    ID = 2812,
    CheckFirst = function()
        local level = UnitLevel("target")
        if level == -1 or level > UnitLevel("player") then
            return false
        end
        
        local ct = UnitCreatureType("target")
        return UnitLevel("target") <= UnitLevel("player")
            and (ct == L["Demon"]
                or ct == L["Dragonkin"]
                or ct == L["Elemental"]
                or ct == L["Undead"])
    end
}

------------------------------------------------------------------- retribution
a.spells["The Art of War"] = { ID = 59578 }

a.spells["Free Exorsism"] = {
    ID = 879,
    CheckFirst = function()
        return c.HasBuff("The Art of War")
    end
}

a.spells["Free Exorsism against Undead"] = {
    ID = 879,
    CheckFirst = function()
        return c.HasBuff("The Art of War")
            and UnitCreatureType("target") == L["Undead"]
    end
}

a.spells["Templar's Verdict"] = {
    ID = 85256,
    CheckFirst = function()
        return a.hasThreeHolyPower()
    end
}

a.spells["Zealotry"] = {
    ID = 85696,
    NonGCD = true,
    FlashColor = "yellow",
}

a.spells["Inquisition"] = {
    ID = 84963,
    Buff = "Inquisition",
    BuffUnit = "player",
    EarlyRefresh = 3,
    CheckFirst = function()
        return a.hasThreeHolyPower()
    end
}
